@@ -22,6 +22,7 @@
 #include <glib/gi18n.h>
 #include <tepl/tepl.h>
 #include "latexila-latex-commands.h"
+#include "latexila-settings.h"
 #include "latexila-utils.h"
 
 struct _LatexilaAppPrivate
@@ -243,8 +244,8 @@ latexila_app_startup (GApplication *g_app)
 	latexila_utils_migrate_latexila_to_gnome_latex ();
 	add_action_entries (app);
 	latexila_latex_commands_add_action_infos (GTK_APPLICATION (app));
-	latexila_utils_register_icons ();
 	setup_theme_extension (app);
+	_latexila_settings_setup (latexila_settings_get_singleton ());
 }
 
 static void
