@@ -18,6 +18,7 @@
  */
 
 #include "latexila-settings.h"
+#include <tepl/tepl.h>
 
 /**
  * SECTION:settings
@@ -108,6 +109,20 @@ _latexila_settings_unref_singleton (void)
 	 */
 }
 
+void
+_latexila_settings_setup (LatexilaSettings *self)
+{
+	TeplSettings *tepl_settings;
+
+	g_return_if_fail (LATEXILA_IS_SETTINGS (self));
+
+	tepl_settings = tepl_settings_get_singleton ();
+	tepl_settings_provide_font_settings (tepl_settings,
+					     self->priv->settings_editor,
+					     "use-default-font",
+					     "editor-font");
+}
+
 /**
  * latexila_settings_peek_editor_settings:
  * @self: the #LatexilaSettings instance.
